@@ -10,7 +10,7 @@ __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "0.1"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "Nov 10, 2012"
 
@@ -22,6 +22,7 @@ from itertools import chain
 from pymatgen.core.periodic_table import smart_element_or_specie, Element
 from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
+from pymatgen.core.units import unitized
 
 
 class Composition(collections.Mapping, collections.Hashable, MSONable):
@@ -359,6 +360,7 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
         return self._natoms
 
     @property
+    @unitized("amu")
     def weight(self):
         """
         Total molecular weight of Composition
@@ -777,4 +779,4 @@ class CompositionError(Exception):
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
