@@ -24,9 +24,18 @@ import collections
 from numbers import Number
 import numbers
 from functools import partial
-from pymatgen.core.physical_constants import N_a, e, EV_TO_HA
+from pymatgen.core.physical_constants import N_a, e
 import re
 
+"""
+Some conversion factors
+"""
+Ha_to_eV = 27.21138386
+Ry_to_eV = Ha_to_eV / 2
+amu_to_kg = 1.660538921e-27
+mile_to_meters = 1609.347219
+bohr_to_angstrom = 0.5291772083
+
 """
 Definitions of supported units. Values below are essentially scaling and
 conversion factors. What matters is the relative values, not the absolute.
@@ -36,16 +45,16 @@ BASE_UNITS = {
     "length": {
         "m": 1,
         "km": 1000,
-        "mile": 1609.347219,
+        "mile": mile_to_meters,
         "ang": 1e-10,
         "cm": 1e-2,
         "pm": 1e-12,
-        "bohr": 0.5291772083e-10,
+        "bohr": bohr_to_angstrom * 1e-10,
     },
     "mass": {
         "kg": 1,
         "g": 1e-3,
-        "amu": 1.660538921e-27,
+        "amu": amu_to_kg,
     },
     "time": {
         "s": 1,
@@ -73,8 +82,8 @@ BASE_UNITS = {
 DERIVED_UNITS = {
     "energy": {
         "eV": {"kg": 1, "m": 2, "s": -2, e: 1},
-        "Ha": {"kg": 1, "m": 2, "s": -2, e / EV_TO_HA: 1},
-        "Ry": {"kg": 1, "m": 2, "s": -2, e / EV_TO_HA / 2: 1},
+        "Ha": {"kg": 1, "m": 2, "s": -2, e * Ha_to_eV: 1},
+        "Ry": {"kg": 1, "m": 2, "s": -2, e * Ry_to_eV: 1},
         "J": {"kg": 1, "m": 2, "s": -2},
         "kJ": {"kg": 1, "m": 2, "s": -2, 1000: 1}
     },
@@ -87,7 +96,9 @@ DERIVED_UNITS = {
     },
     "pressure": {
         "Pa": {"kg": 1, "m": -1, "s": -2},
-        "kPa": {"kg": 1, "m": -1, "s": -2, 1000: 1}
+        "KPa": {"kg": 1, "m": -1, "s": -2, 1000: 1},
+        "MPa": {"kg": 1, "m": -1, "s": -2, 1e6: 1},
+        "GPa": {"kg": 1, "m": -1, "s": -2, 1e9: 1}
     },
     "power": {
         "W": {"m": 2, "kg": 1, "s": -3}
@@ -127,11 +138,19 @@ def _get_si_unit(unit):
     return si_unit[0], BASE_UNITS[unit_type][unit]
 
 
+class UnitError(BaseException):
+    """
+    Exception class for unit errors.
+    """
+
+
 class Unit(collections.Mapping):
     """
     Represents a unit, e.g., "m" for meters, etc. Supports compound units.
     Only integer powers are supported for units.
     """
+    Error = UnitError
+
     def __init__(self, unit_def):
         """
         Constructs a unit.
@@ -150,7 +169,12 @@ class Unit(collections.Mapping):
             for m in re.finditer("([A-Za-z]+)\s*\^*\s*([\-0-9]*)", unit_def):
                 p = m.group(2)
                 p = 1 if not p else int(p)
-                unit[m.group(1)] += p
+                k = m.group(1)
+                for utype in ALL_UNITS.values():
+                    for u in utype.keys():
+                        if u.lower() == k.lower():
+                            k = u
+                unit[k] += p
         else:
             unit = {k: v for k, v in dict(unit_def).items() if v != 0}
 
@@ -282,6 +306,7 @@ class FloatWithUnit(float):
     >>> c.to("eV")
     32.932522246000005 eV
     """
+    Error = UnitError
 
     def __new__(cls, val, unit, unit_type=None):
         return float.__new__(cls, val)
@@ -421,6 +446,8 @@ class ArrayWithUnit(np.ndarray):
     >>> c.to("eV")
     array([ 28.21138386,  56.42276772]) eV
     """
+    Error = UnitError
+
     def __new__(cls, input_array, unit, unit_type=None):
         # Input array is an already formed ndarray instance
         # We first cast to be our class type
@@ -570,21 +597,79 @@ class ArrayWithUnit(np.ndarray):
 
 
 Energy = partial(FloatWithUnit, unit_type="energy")
+"""
+A float with an energy unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., eV, kJ, etc. Must be valid unit or UnitError is raised.
+"""
 EnergyArray = partial(ArrayWithUnit, unit_type="energy")
 
 Length = partial(FloatWithUnit, unit_type="length")
+"""
+A float with a length unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., m, ang, bohr, etc. Must be valid unit or UnitError is
+        raised.
+"""
 LengthArray = partial(ArrayWithUnit, unit_type="length")
 
 Mass = partial(FloatWithUnit, unit_type="mass")
+"""
+A float with a mass unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., amu, kg, etc. Must be valid unit or UnitError is
+        raised.
+"""
 MassArray = partial(ArrayWithUnit, unit_type="mass")
 
 Temp = partial(FloatWithUnit, unit_type="temperature")
+"""
+A float with a temperature unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., K. Only K (kelvin) is supported.
+"""
 TempArray = partial(ArrayWithUnit, unit_type="temperature")
 
 Time = partial(FloatWithUnit, unit_type="time")
+"""
+A float with a time unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., s, min, h. Must be valid unit or UnitError is
+        raised.
+"""
 TimeArray = partial(ArrayWithUnit, unit_type="time")
 
 Charge = partial(FloatWithUnit, unit_type="charge")
+"""
+A float with a charge unit.
+
+Args:
+    val:
+        Value
+    unit:
+        Units. E.g., C, e (electron charge). Must be valid unit or UnitError
+        is raised.
+"""
 ChargeArray = partial(ArrayWithUnit, unit_type="charge")
 
 
@@ -603,7 +688,7 @@ def obj_with_unit(obj, unit):
     if isinstance(obj, numbers.Number):
         return FloatWithUnit(obj, unit=unit, unit_type=unit_type)
     elif isinstance(obj, collections.Mapping):
-        return {k: obj_with_unit(v) for k,v in obj.items()}
+        return {k: obj_with_unit(v, unit) for k,v in obj.items()}
     else:
         return ArrayWithUnit(obj, unit=unit, unit_type=unit_type)
 
@@ -616,8 +701,15 @@ def unitized(unit):
     unit information. For mapping types, the values are assigned units.
 
     Args:
-        units:
-            Specific units (eV, Ha, m, ang, etc.).
+        unit:
+            Specific unit (eV, Ha, m, ang, etc.).
+
+    Example usage::
+
+        @unitized(unit="kg")
+        def get_mass():
+            return 123.45
+
     """
     def wrap(f):
         def wrapped_f(*args, **kwargs):
@@ -639,13 +731,6 @@ def unitized(unit):
     return wrap
 
 
-class UnitError(BaseException):
-    """
-    Exception class for unit errors.
-    """
-    pass
-
-
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
