@@ -27,6 +27,7 @@ import numpy as np
 from pymatgen.core.periodic_table import Element, Specie
 from pymatgen.util.io_utils import zopen
 from pymatgen.util.coord_utils import in_coord_list_pbc
+from pymatgen.util.string_utils import remove_non_ascii
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.core.composition import Composition
@@ -51,7 +52,9 @@ class CifParser(object):
         self._occupancy_tolerance = occupancy_tolerance
         if isinstance(filename, basestring):
             with zopen(filename, "r") as f:
-                self._cif = CifFile.ReadCif(f)
+                # We use this round-about way to clean up the CIF first.
+                stream = cStringIO.StringIO(_clean_cif(f.read()))
+                self._cif = CifFile.ReadCif(stream)
         else:
             self._cif = CifFile.ReadCif(filename)
 
@@ -70,8 +73,8 @@ class CifParser(object):
         Returns:
             CifParser
         """
-        output = cStringIO.StringIO(cif_string)
-        return CifParser(output, occupancy_tolerance)
+        stream = cStringIO.StringIO(_clean_cif(cif_string))
+        return CifParser(stream, occupancy_tolerance)
 
     def _unique_coords(self, coord_in):
         """
@@ -89,9 +92,9 @@ class CifParser(object):
         """
         Generate structure from part of the cif.
         """
-        lengths = [float_from_str(data["_cell_length_" + i])
+        lengths = [str2float(data["_cell_length_" + i])
                    for i in ["a", "b", "c"]]
-        angles = [float_from_str(data["_cell_angle_" + i])
+        angles = [str2float(data["_cell_angle_" + i])
                   for i in ["alpha", "beta", "gamma"]]
         lattice = Lattice.from_lengths_and_angles(lengths, angles)
         try:
@@ -112,9 +115,10 @@ class CifParser(object):
             return ""
 
         try:
-            oxi_states = {data["_atom_type_symbol"][i]:
-                          float_from_str(data["_atom_type_oxidation_number"][i])
-                          for i in xrange(len(data["_atom_type_symbol"]))}
+            oxi_states = {
+                data["_atom_type_symbol"][i]:
+                str2float(data["_atom_type_oxidation_number"][i])
+                for i in xrange(len(data["_atom_type_symbol"]))}
         except (ValueError, KeyError):
             oxi_states = None
 
@@ -127,11 +131,11 @@ class CifParser(object):
                             oxi_states[data["_atom_site_type_symbol"][i]])
             else:
                 el = Element(symbol)
-            x = float_from_str(data["_atom_site_fract_x"][i])
-            y = float_from_str(data["_atom_site_fract_y"][i])
-            z = float_from_str(data["_atom_site_fract_z"][i])
+            x = str2float(data["_atom_site_fract_x"][i])
+            y = str2float(data["_atom_site_fract_y"][i])
+            z = str2float(data["_atom_site_fract_z"][i])
             try:
-                occu = float_from_str(data["_atom_site_occupancy"][i])
+                occu = str2float(data["_atom_site_occupancy"][i])
             except (KeyError, ValueError):
                 occu = 1
             if occu > 0:
@@ -178,7 +182,7 @@ class CifParser(object):
         for k, v in self._cif.items():
             try:
                 structures.append(self._get_structure(v, primitive))
-            except KeyError as ex:
+            except KeyError:
                 pass
         return structures
 
@@ -305,7 +309,26 @@ class CifWriter:
             f.write(self.__str__())
 
 
-def float_from_str(text):
+def _clean_cif(s):
+    """
+    Removes non-ASCII and some unsupported _cgraph fields from the cif
+    string
+    """
+    clean = []
+    lines = s.split("\n")
+    while len(lines) > 0:
+        l = lines.pop(0)
+        if l.strip().startswith("_cgraph"):
+            l = lines.pop(0)
+            while not (l.strip().startswith("_") or l.strip() == "loop_"):
+                l = lines.pop(0)
+            continue
+        elif not l.strip().startswith("_eof"):
+            clean.append(remove_non_ascii(l))
+    return "\n".join(clean)
+
+
+def str2float(text):
     """
     Remove uncertainty brackets from strings and return the float.
     """
