@@ -220,7 +220,20 @@ def list_strings(arg):
         return arg
 
 
-###############################################################################
+def remove_non_ascii(s):
+    """
+    Remove non-ascii characters in a file.
+
+    Args:
+        s:
+            Input string
+
+    Returns:
+        String with all non-ascii characters removed.
+    """
+    return "".join(i for i in s if ord(i) < 128)
+
+
 def stream_has_colours(stream):
     """
     True if stream supports colours. Python cookbook, #475186
